//
//  AppDelegate.m
//  MyKouponSample
//
//  Created by Brian Reinhart on 9/27/13.
//  Copyright (c) 2013 Koupon Media. All rights reserved.
//

#import "AppDelegate.h"

@implementation AppDelegate

@synthesize apiData;
@synthesize kouponSDK;
@synthesize window;
@synthesize deviceTokenData;

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
    // Override point for customization after application launch.
    apiData = [[APIData alloc] initWithFile:[[NSBundle mainBundle] pathForResource:@"KouponAPIData" ofType:@"plist"]];
    
    //Init the Koupon SDK using the KouponConfiguration.plist file
    kouponSDK = [[Koupon alloc] init];
    [kouponSDK createConsumerIdentity:[NSMutableDictionary dictionary] withOptionalQueryData:nil];
    
    [[KouponGimbalManager sharedManager] initGimbalServicesWithDelegate:self KouponSDK:kouponSDK];
    
    [[UIApplication sharedApplication] registerForRemoteNotificationTypes:(UIRemoteNotificationTypeBadge | UIRemoteNotificationTypeSound | UIRemoteNotificationTypeAlert)];
    [UIApplication sharedApplication].applicationIconBadgeNumber = 0;
    

    return YES;
    
}
							
- (void)applicationWillResignActive:(UIApplication *)application
{

}

- (void)applicationDidEnterBackground:(UIApplication *)application
{

}

- (void)applicationWillEnterForeground:(UIApplication *)application
{
    // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
    [UIApplication sharedApplication].applicationIconBadgeNumber = 0;
}

- (void)applicationDidBecomeActive:(UIApplication *)application
{
}

- (void)applicationWillTerminate:(UIApplication *)application
{
    // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
}

#pragma mark -Push Notification Functions
- (void) application:(UIApplication *)application didReceiveLocalNotification:(UILocalNotification *)notification
{
    [UIApplication sharedApplication].applicationIconBadgeNumber++;
    [[[UIAlertView alloc] initWithTitle:@"Location Event Fired" message:notification.alertBody delegate:self cancelButtonTitle:@"Cool" otherButtonTitles:nil] show];
    
}
- (void) application:(UIApplication*) application didReceiveRemoteNotification:(NSDictionary *)userInfo
{
    [[[UIAlertView alloc] initWithTitle:@"Push Message Received" message:[userInfo objectForKey:@"alert"] delegate:nil cancelButtonTitle:@"Cancel" otherButtonTitles:@"View", nil] show];
    [UIApplication sharedApplication].applicationIconBadgeNumber = 0;
}
- (void) application:(UIApplication*) application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken
{
    deviceTokenData = [deviceToken copy];
    
    if (Koupon.consumerId) {
        //Send the request
        NSDictionary *regDict = @{@"device_id": deviceToken, @"platform": @"ios"};
        [[kouponSDK reportAppEvent:@"pushreg" withData:(NSMutableDictionary*)regDict] sendRequestAsyncOnSuccess:^(NSMutableDictionary* response){
            NSLog(@"MySampleApp->Successfully sent Device Token to Koupon Media");
        } OnFailure:^(NSMutableDictionary* response){
            NSLog(@"MySampleApp->Failed to send Device Token to Koupon Media");
        }];
    }
    

}

#pragma mark -Koupon Gimbal Manager Delegate Methods

- (void)didEnterGeofence:(KMGeofenceEvent *)geoEvent
{
    NSLog(@"did get place event %@", geoEvent.placeEvent.place.name);
    NSString* eventVerb = geoEvent.placeEvent.eventType == 1 ? @"entered" : @"left";
    NSString* message = [NSString stringWithFormat:@"You have %@ %@", eventVerb, geoEvent.placeEvent.place.name];
    
    UILocalNotification* placeNotification = [[UILocalNotification alloc] init];
    placeNotification.fireDate = [NSDate date];
    placeNotification.alertBody = message;
    [[UIApplication sharedApplication] presentLocalNotificationNow:placeNotification ];
    
    
}

@end
